@@ -1,11 +1,10 @@
-#' @rdname hr
+#' @rdname hrest
 #' @export
 hr_mcp <- function(x, ...) {
   UseMethod("hr_mcp", x)
 }
 
 #' @export
-#' @rdname hr
 hr_mcp.track_xy <- function(x, levels = 0.95, keep.data = TRUE, ...) {
 
   # check levels
@@ -18,7 +17,7 @@ hr_mcp.track_xy <- function(x, levels = 0.95, keep.data = TRUE, ...) {
   sqd <- (xy$x_ - mxy[1])^2 + (xy$y_ - mxy[2])^2
   qts <- stats::quantile(sqd, levels)
   geometry <- lapply(qts, function(i) chull_mcp(xy[sqd <= i, ]))
-  geometry <- sf::st_as_sfc(geometry, crs = as.character(get_crs(x)))
+  geometry <- sf::st_as_sfc(geometry, crs = get_crs(x))
   mcps <- sf::st_sf(level = levels, what = "estimate", area = sf::st_area(geometry), geometry)
   mcp <- list(mcp = mcps, levels = levels, estimator = "mcp",
               crs = get_crs(x),
